You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:25:24 UTC

svn commit: r1591062 [13/15] - in /openoffice/trunk/main: registry/inc/registry/ registry/tools/ rhino/ ridljar/com/sun/star/lib/util/ ridljar/com/sun/star/uno/ rsc/inc/ rsc/source/parser/ rsc/source/rscpp/ sal/inc/osl/ sal/inc/rtl/ sal/inc/sal/ sal/in...

Modified: openoffice/trunk/main/vcl/source/gdi/region.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/region.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/region.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/region.cxx Tue Apr 29 19:25:03 2014
@@ -130,7 +130,7 @@ namespace 
                 OSL_ASSERT(aStart.X() == aEnd.X());
 
                 // Sort y-coordinates to simplify the algorithm and store the
-                // direction seperately.  The direction is calculated as it is
+                // direction separately.  The direction is calculated as it is
                 // in other places (but seems to be the wrong way.)
                 const long nTop (::std::min(aStart.Y(), aEnd.Y()));
                 const long nBottom (::std::max(aStart.Y(), aEnd.Y()));
@@ -218,7 +218,7 @@ namespace 
                 pRegionBand->InsertLine( aPoly.GetPoint(nPoint-1), aPoly.GetPoint(nPoint), nLineID++ );
             }
 
-            // close polygon with line from first point to last point, if neccesary
+            // close polygon with line from first point to last point, if necessary
             const Point rLastPoint = aPoly.GetPoint(nSize-1);
             const Point rFirstPoint = aPoly.GetPoint(0);
 
@@ -586,7 +586,7 @@ bool Region::Union( const Rectangle& rRe
     const long nRight(std::max(rRect.Left(), rRect.Right()));
     const long nBottom(std::max(rRect.Top(), rRect.Bottom()));
 
-    // insert bands if the boundaries are not allready in the list
+    // insert bands if the boundaries are not already in the list
     pNew->InsertBands(nTop, nBottom);
 
     // process union
@@ -679,7 +679,7 @@ bool Region::Intersect( const Rectangle&
     const long nRight(std::max(rRect.Left(), rRect.Right()));
     const long nBottom(std::max(rRect.Top(), rRect.Bottom()));
 
-    // insert bands if the boundaries are not allready in the list
+    // insert bands if the boundaries are not already in the list
     pNew->InsertBands(nTop, nBottom);
 
     // process intersect
@@ -712,7 +712,7 @@ bool Region::Exclude( const Rectangle& r
 
     if(IsNull())
     {
-        // error; cannnot exclude from null region since this is not representable
+        // error; cannot exclude from null region since this is not representable
         // in the data
         OSL_ENSURE(false, "Region::Exclude error: Cannot exclude from null region (!)");
         return true;
@@ -760,7 +760,7 @@ bool Region::Exclude( const Rectangle& r
     const long nRight(std::max(rRect.Left(), rRect.Right()));
     const long nBottom(std::max(rRect.Top(), rRect.Bottom()));
 
-    // insert bands if the boundaries are not allready in the list
+    // insert bands if the boundaries are not already in the list
     pNew->InsertBands(nTop, nBottom);
 
     // process exclude
@@ -794,7 +794,7 @@ bool Region::XOr( const Rectangle& rRect
 
     if(IsNull())
     {
-        // error; cannnot exclude from null region since this is not representable
+        // error; cannot exclude from null region since this is not representable
         // in the data
         OSL_ENSURE(false, "Region::XOr error: Cannot XOr with null region (!)");
         return true;
@@ -845,7 +845,7 @@ bool Region::XOr( const Rectangle& rRect
     const long nRight(std::max(rRect.Left(), rRect.Right()));
     const long nBottom(std::max(rRect.Top(), rRect.Bottom()));
 
-    // insert bands if the boundaries are not allready in the list
+    // insert bands if the boundaries are not already in the list
     pNew->InsertBands(nTop, nBottom);
 
     // process xor
@@ -1095,7 +1095,7 @@ bool Region::Exclude( const Region& rReg
 
     if(IsNull())
     {
-        // error; cannnot exclude from null region since this is not representable
+        // error; cannot exclude from null region since this is not representable
         // in the data
         OSL_ENSURE(false, "Region::Exclude error: Cannot exclude from null region (!)");
         return true;
@@ -1167,7 +1167,7 @@ bool Region::XOr( const Region& rRegion 
 
 	if ( rRegion.IsNull() )
     {
-        // error; cannnot exclude null region from local since this is not representable
+        // error; cannot exclude null region from local since this is not representable
         // in the data
         OSL_ENSURE(false, "Region::XOr error: Cannot XOr with null region (!)");
 		return true;
@@ -1182,7 +1182,7 @@ bool Region::XOr( const Region& rRegion 
 
     if(IsNull())
     {
-        // error; cannnot exclude from null region since this is not representable
+        // error: cannot exclude from null region since this is not representable
         // in the data
         OSL_ENSURE(false, "Region::XOr error: Cannot XOr with null region (!)");
         return false;
@@ -1389,7 +1389,7 @@ bool Region::IsInside( const Point& rPoi
 	//	return mpImplRegion->getRegionPolyPoly()->IsInside( rPoint );
     //}
 
-    // ensure RegionBand existance
+    // ensure RegionBand existence
     const RegionBand* pRegionBand = GetAsRegionBand();
 
     if(pRegionBand)
@@ -1703,7 +1703,7 @@ void Region::GetRegionRectangles(Rectang
     // clear returnvalues
     rTarget.clear();
 
-    // ensure RegionBand existance
+    // ensure RegionBand existence
     const RegionBand* pRegionBand = GetAsRegionBand();
 
     if(pRegionBand)

Modified: openoffice/trunk/main/vcl/source/gdi/regionband.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/regionband.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/regionband.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/regionband.cxx Tue Apr 29 19:25:03 2014
@@ -788,7 +788,7 @@ void RegionBand::InsertBands(long nTop, 
 			break;
         }
 
-		// insert bands between two bands if neccessary
+		// insert bands between two bands if necessary
 		if ( pBand->mpNextBand )
 		{
 			if ( (pBand->mnYBottom + 1) < pBand->mpNextBand->mnYTop )
@@ -977,7 +977,7 @@ void RegionBand::Union(const RegionBand&
 
     while ( pBand )
 	{
-		// insert bands if the boundaries are not allready in the list
+		// insert bands if the boundaries are not already in the list
 		InsertBands(pBand->mnYTop, pBand->mnYBottom);
 
 		// process all elements of the list
@@ -1094,7 +1094,7 @@ void RegionBand::Intersect(const RegionB
 		
     while ( pBand )
     {
-	    // insert bands if the boundaries are not allready in the list
+	    // insert bands if the boundaries are not already in the list
 	    InsertBands( pBand->mnYTop, pBand->mnYBottom );
 
 	    // process all elements of the list
@@ -1127,7 +1127,7 @@ void RegionBand::Intersect(const RegionB
 	    pBand = pBand->mpNextBand;
     }
 
-    // remove all untouched bands if bands allready left
+    // remove all untouched bands if bands already left
     ImplRegionBand* pPrevBand = 0;
     pBand = mpFirstBand;
 
@@ -1168,7 +1168,7 @@ bool RegionBand::Exclude(const RegionBan
 
     while ( pBand )
     {
-	    // insert bands if the boundaries are not allready in the list
+	    // insert bands if the boundaries are not already in the list
 	    InsertBands( pBand->mnYTop, pBand->mnYBottom );
 
 	    // process all elements of the list
@@ -1225,7 +1225,7 @@ void RegionBand::XOr(const RegionBand& r
 
     while ( pBand )
     {
-	    // insert bands if the boundaries are not allready in the list
+	    // insert bands if the boundaries are not already in the list
 	    InsertBands( pBand->mnYTop, pBand->mnYBottom );
 
 	    // process all elements of the list

Modified: openoffice/trunk/main/vcl/source/gdi/textlayout.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/gdi/textlayout.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/gdi/textlayout.cxx (original)
+++ openoffice/trunk/main/vcl/source/gdi/textlayout.cxx Tue Apr 29 19:25:03 2014
@@ -147,7 +147,7 @@ namespace vcl
         // normally, controls simulate "zoom" by "zooming" the font. This is responsible for (part of) the discrepancies
         // between text in Writer and text in controls in Writer, though both have the same font.
         // So, if we have a zoom set at the control, then we do not scale the font, but instead modify the map mode
-        // to accomodate for the zoom.
+        // to accommodate for the zoom.
         aTargetMapMode.SetScaleX( m_aZoom );    // TODO: shouldn't this be "current_scale * zoom"?
         aTargetMapMode.SetScaleY( m_aZoom );
 

Modified: openoffice/trunk/main/vcl/source/glyphs/gcach_layout.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/glyphs/gcach_layout.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/glyphs/gcach_layout.cxx (original)
+++ openoffice/trunk/main/vcl/source/glyphs/gcach_layout.cxx Tue Apr 29 19:25:03 2014
@@ -550,7 +550,7 @@ bool IcuLayoutEngine::operator()( Server
             else
             {
                 // Hack, find next +ve width glyph and calculate current
-                // glyph width by substracting the two posituons
+                // glyph width by subtracting the two positions
                 const IcuPosition* pNextPos = pPos+1;
                 for ( int j = i + 1; j <= nRawRunGlyphCount; ++j, ++pNextPos )
                 {

Modified: openoffice/trunk/main/vcl/source/glyphs/glyphcache.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/glyphs/glyphcache.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/glyphs/glyphcache.cxx (original)
+++ openoffice/trunk/main/vcl/source/glyphs/glyphcache.cxx Tue Apr 29 19:25:03 2014
@@ -410,7 +410,7 @@ ServerFont::ServerFont( const ImplFontSe
     mbCollectedZW( false )
 {
     // TODO: move update of mpFontEntry into FontEntry class when
-    // it becomes reponsible for the ServerFont instantiation
+    // it becomes responsible for the ServerFont instantiation
     ((ImplServerFontEntry*)rFSD.mpFontEntry)->SetServerFont( this );
 
     if( rFSD.mnOrientation != 0 )

Modified: openoffice/trunk/main/vcl/source/glyphs/graphite_layout.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/glyphs/graphite_layout.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/glyphs/graphite_layout.cxx (original)
+++ openoffice/trunk/main/vcl/source/glyphs/graphite_layout.cxx Tue Apr 29 19:25:03 2014
@@ -358,7 +358,7 @@ std::pair<float,float> GraphiteLayout::G
     rGlyph2Char[size()] = nFirstCharInCluster;
 
     // can we break before this cluster?
-    // Glyphs may have either a positive or negative breakWeight refering to
+    // Glyphs may have either a positive or negative breakWeight referring to
     // the position after or before the glyph respectively
     int nPrevBreakWeight = 0;
     if (nFirstGlyphInCluster > 0)
@@ -700,7 +700,7 @@ gr::Segment * GraphiteLayout::CreateSegm
 
     gr::Segment * pSegment = NULL;
 
-    // Set the SalLayouts values to be the inital ones.
+    // Set the SalLayouts values to be the initial ones.
     SalLayout::AdjustLayout(rArgs);
     // TODO check if this is needed
     if (mnUnitsPerPixel > 1)
@@ -1279,7 +1279,7 @@ void GraphiteLayout::kashidaJustify(std:
 void GraphiteLayout::GetCaretPositions( int nArraySize, sal_Int32* pCaretXArray ) const
 {
     // For each character except the last discover the caret positions
-    // immediatly before and after that character.
+    // immediately before and after that character.
     // This is used for underlines in the GUI amongst other things.
     // It may be used from MultiSalLayout, in which case it must take into account
     // glyphs that have been moved.
@@ -1491,7 +1491,7 @@ int GraphiteLayout::GetNextGlyphs( int l
 
 void GraphiteLayout::MoveGlyph( int nGlyphIndex, long nNewPos )
 {
-    // TODO it might be better to actualy implement simplify properly, but this
+    // TODO it might be better to actually implement simplify properly, but this
     // needs to be done carefully so the glyph/char maps are maintained
     // If a glyph has been dropped then it wasn't returned by GetNextGlyphs, so
     // the index here may be wrong

Modified: openoffice/trunk/main/vcl/source/window/menu.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/window/menu.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/window/menu.cxx (original)
+++ openoffice/trunk/main/vcl/source/window/menu.cxx Tue Apr 29 19:25:03 2014
@@ -3401,7 +3401,7 @@ Window* MenuBar::ImplCreate( Window* pPa
     long nHeight = pMenu->ImplCalcSize( pWindow ).Height();
 
     // depending on the native implementation or the displayable flag
-    // the menubar windows is supressed (ie, height=0)
+    // the menubar windows is suppressed (ie, height=0)
     if( !((MenuBar*) pMenu)->IsDisplayable() || 
         ( pMenu->ImplGetSalMenu() && pMenu->ImplGetSalMenu()->VisibleMenuBar() ) )
         nHeight = 0;
@@ -6023,7 +6023,7 @@ void MenuBarWindow::ImplLayoutChanged()
         long nHeight = pMenu->ImplCalcSize( this ).Height();
 
         // depending on the native implementation or the displayable flag
-        // the menubar windows is supressed (ie, height=0)
+        // the menubar windows is suppressed (ie, height=0)
         if( !((MenuBar*) pMenu)->IsDisplayable() || 
             ( pMenu->ImplGetSalMenu() && pMenu->ImplGetSalMenu()->VisibleMenuBar() ) )
             nHeight = 0;

Modified: openoffice/trunk/main/vcl/source/window/printdlg.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/window/printdlg.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/window/printdlg.cxx (original)
+++ openoffice/trunk/main/vcl/source/window/printdlg.cxx Tue Apr 29 19:25:03 2014
@@ -92,7 +92,7 @@ bool PrintDialog::PrintPreviewWindow::us
         {
             // get service provider
             Reference< XMultiServiceFactory > xSMgr( unohelper::GetMultiServiceFactory() );
-            // create configuration hierachical access name
+            // create configuration hierarchical access name
             if( xSMgr.is() )
             {
                 try

Modified: openoffice/trunk/main/vcl/source/window/split.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/window/split.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/window/split.cxx (original)
+++ openoffice/trunk/main/vcl/source/window/split.cxx Tue Apr 29 19:25:03 2014
@@ -400,10 +400,10 @@ void Splitter::ImplKbdTracking( KeyCode 
 		Point aNewPos;
         Size aSize = mpRefWin->GetOutputSize();
         Point aPos = GetPosPixel();
-        // depending on the position calc allows continous moves or snaps to row/columns
-        // continous mode is active when position is at the origin or end of the splitter
+        // depending on the position calc allows continuous moves or snaps to row/columns
+        // continuous mode is active when position is at the origin or end of the splitter
         // otherwise snap mode is active
-        // default here is snap, holding shift sets continous mode
+        // default here is snap, holding shift sets continuous mode
         if( mbHorzSplit )
             aNewPos = Point( ImplSplitterActive() ? aPos.X() : mnSplitPos, aKeyCode.IsShift() ? 0 : aSize.Height()/2);
         else

Modified: openoffice/trunk/main/vcl/source/window/tabdlg.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/window/tabdlg.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/window/tabdlg.cxx (original)
+++ openoffice/trunk/main/vcl/source/window/tabdlg.cxx Tue Apr 29 19:25:03 2014
@@ -244,7 +244,7 @@ TabDialog::~TabDialog()
 
 void TabDialog::Resize()
 {
-// !!! In the future the controls should be automaticly rearrange
+// !!! In the future the controls should be automatically rearrange
 // !!! if the window is resized
 // !!! if ( !IsRollUp() )
 // !!!		ImplPosControls();

Modified: openoffice/trunk/main/vcl/source/window/window.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/window/window.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/window/window.cxx (original)
+++ openoffice/trunk/main/vcl/source/window/window.cxx Tue Apr 29 19:25:03 2014
@@ -1659,7 +1659,7 @@ void Window::ImplCallInitShow()
 
 // -----------------------------------------------------------------------
 
-void Window::ImplAddDel( ImplDelData* pDel ) // TODO: make "const" when incompatiblity ok
+void Window::ImplAddDel( ImplDelData* pDel ) // TODO: make "const" when incompatibility ok
 {
     DBG_ASSERT( !pDel->mpWindow, "Window::ImplAddDel(): cannot add ImplDelData twice !" );
     if( !pDel->mpWindow )
@@ -1672,7 +1672,7 @@ void Window::ImplAddDel( ImplDelData* pD
 
 // -----------------------------------------------------------------------
 
-void Window::ImplRemoveDel( ImplDelData* pDel ) // TODO: make "const" when incompatiblity ok
+void Window::ImplRemoveDel( ImplDelData* pDel ) // TODO: make "const" when incompatibility ok
 {
     pDel->mpWindow = NULL;      // #112873# pDel is not associated with a Window anymore
     if ( mpWindowImpl->mpFirstDel == pDel )
@@ -5120,7 +5120,7 @@ void Window::ImplNotifyKeyMouseCommandEv
         }
     }
 
-    // #82968# notify event listeners for mouse and key events seperately and
+    // #82968# notify event listeners for mouse and key events separately and
     // not in PreNotify ( as for focus listeners )
     // this allows for procesing those events internally first and pass it to
     // the toolkit later
@@ -7388,7 +7388,7 @@ void Window::SetPosSizePixel( long nX, l
 
         // Resize should be called directly. If we havn't
         // set the correct size, we get a second resize from
-        // the system with the correct size. This can be happend
+        // the system with the correct size. This can happen
         // if the size is to small or to large.
         ImplHandleResize( pWindow, nWidth, nHeight );
     }

Modified: openoffice/trunk/main/vcl/source/window/winproc.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/window/winproc.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/window/winproc.cxx (original)
+++ openoffice/trunk/main/vcl/source/window/winproc.cxx Tue Apr 29 19:25:03 2014
@@ -963,7 +963,7 @@ static long ImplHandleKey( Window* pWind
 
     // allow application key listeners to remove the key event
     // but make sure we're not forwarding external KeyEvents, (ie where bForward is sal_False)
-    // becasue those are coming back from the listener itself and MUST be processed
+    // because those are coming back from the listener itself and MUST be processed
     KeyEvent aKeyEvent( (xub_Unicode)nCharCode, aKeyCode, nRepeat );
     if( bForward )
     {
@@ -1559,7 +1559,7 @@ static long ImplHandleWheelEvent( Window
 
 static void ImplHandlePaint( Window* pWindow, const Rectangle& rBoundRect, bool bImmediateUpdate )
 {
-    // give up background save when sytem paints arrive
+    // give up background save when system paints arrive
     Window* pSaveBackWin = pWindow->ImplGetWindowImpl()->mpFrameData->mpFirstBackWin;
     while ( pSaveBackWin )
     {

Modified: openoffice/trunk/main/vcl/test/dndtest.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/test/dndtest.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/test/dndtest.cxx (original)
+++ openoffice/trunk/main/vcl/test/dndtest.cxx Tue Apr 29 19:25:03 2014
@@ -341,7 +341,7 @@ void SAL_CALL MyDragAndDropListener::dro
 
 void SAL_CALL MyDragAndDropListener::dragDropEnd( const DragSourceDropEvent& dsde ) throw(RuntimeException)
 {
-	printf( "XDragSourceListener::dropDropEnd called ( Window: %p, %s ).\n", m_pWindow, dsde.DropSuccess ? "sucess" : "failed" );
+	printf( "XDragSourceListener::dropDropEnd called ( Window: %p, %s ).\n", m_pWindow, dsde.DropSuccess ? "success" : "failed" );
 }
 
 // -----------------------------------------------------------------------

Modified: openoffice/trunk/main/vcl/unx/generic/app/i18n_ic.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/app/i18n_ic.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/app/i18n_ic.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/app/i18n_ic.cxx Tue Apr 29 19:25:03 2014
@@ -562,7 +562,7 @@ SalI18N_InputContext::SupportInputMethod
     if ( pIMStyles != NULL )
     {
         // check whether the XIM supports one of the desired styles
-        // only a single preedit and a single status style must occure
+        // only a single preedit and a single status style must occur
         // in a inpuut method style. Hideki said so, so i trust him
         for ( int nStyle = 0; nStyle < pIMStyles->count_styles; nStyle++ )
         {

Modified: openoffice/trunk/main/vcl/unx/generic/app/saldata.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/app/saldata.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/app/saldata.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/app/saldata.cxx Tue Apr 29 19:25:03 2014
@@ -533,7 +533,7 @@ void SalXLib::XError( Display *pDisplay,
 			static Bool bOnce = False;
 			if ( !bOnce )
 			{
-                std::fprintf(stderr, "X-Error occured in a request for X_OpenFont\n");
+                std::fprintf(stderr, "X-Error occurred in a request for X_OpenFont\n");
                 EmitFontpathWarning();
 
 				bOnce = True ;

Modified: openoffice/trunk/main/vcl/unx/generic/app/saldisp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/app/saldisp.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/app/saldisp.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/app/saldisp.cxx Tue Apr 29 19:25:03 2014
@@ -1408,8 +1408,8 @@ sal_uInt16 SalDisplay::GetKeyCode( KeySy
                 break;
             // - - - - - Sun X-Server Tastatur ??? - - - - - - - - - - - -
             case XK_L1: // XK_F11:
-                nKey = KEY_F11; // on a sun keyboard this actually is usally SunXK_Stop,
-                // but VCL doesn't have a key defintion for that
+                nKey = KEY_F11; // on a sun keyboard this actually is usually SunXK_Stop,
+                // but VCL doesn't have a key definition for that
                 break;
             case XK_L2: // XK_F12:
 				if ( GetServerVendor() == vendor_sun )
@@ -1714,7 +1714,7 @@ KeySym SalDisplay::GetKeySym( XKeyEvent 
 			case XLookupBoth:
 			case XLookupChars:
 
-				/* nothing to, char allready in pPrintable */
+				/* nothing to, char already in pPrintable */
 				break;
 		}
 	}

Modified: openoffice/trunk/main/vcl/unx/generic/app/wmadaptor.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/app/wmadaptor.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/app/wmadaptor.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/app/wmadaptor.cxx Tue Apr 29 19:25:03 2014
@@ -1493,7 +1493,7 @@ void WMAdaptor::setFrameTypeAndDecoratio
      
     // set transientFor hint
     /*  #91030# dtwm will not map a dialogue if the transient
-     *  window is iconified. This is deemed undesireable because
+     *  window is iconified. This is deemed undesirable because
      *  message boxes do not get mapped, so use the root as transient
      *  instead.
      */

Modified: openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.cxx Tue Apr 29 19:25:03 2014
@@ -1024,7 +1024,7 @@ bool SelectionManager::getPasteData( Ato
 	}
 #if OSL_DEBUG_LEVEL > 1
     else
-        fprintf( stderr, "conversion unsuccessfull\n" );
+        fprintf( stderr, "conversion unsuccessful\n" );
 #endif
 	return bSuccess;
 }
@@ -3830,7 +3830,7 @@ void SelectionManager::shutdown() throw(
         osl_terminateThread( m_aThread );
         /*
          * Allow thread to finish before app exits to avoid pulling the carpet
-         * out from under it if pasting is occuring during shutdown
+         * out from under it if pasting is occurring during shutdown
          *
          * a) allow it to have the Mutex and 
          * b) reschedule to allow it to complete callbacks to any

Modified: openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.hxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.hxx Tue Apr 29 19:25:03 2014
@@ -67,7 +67,7 @@ namespace x11 {
         virtual void fireContentsChanged() = 0;
         virtual com::sun::star::uno::Reference< XInterface > getReference() = 0;
         // returns a reference that will keep the SelectionAdaptor alive until the
-        // refernce is released
+        // reference is released
 	};
 
 	class DropTarget :

Modified: openoffice/trunk/main/vcl/unx/generic/fontmanager/parseAFM.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/fontmanager/parseAFM.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/fontmanager/parseAFM.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/fontmanager/parseAFM.cxx Tue Apr 29 19:25:03 2014
@@ -47,7 +47,7 @@
 
 /* parseAFM.c
  * 
- * This file is used in conjuction with the parseAFM.h header file.
+ * This file is used in conjunction with the parseAFM.h header file.
  * This file contains several procedures that are used to parse AFM
  * files. It is intended to work with an application program that needs
  * font metric information. The program can be used as is by making a

Modified: openoffice/trunk/main/vcl/unx/generic/fontmanager/parseAFM.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/fontmanager/parseAFM.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/fontmanager/parseAFM.hxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/fontmanager/parseAFM.hxx Tue Apr 29 19:25:03 2014
@@ -36,7 +36,7 @@
 
 /* ParseAFM.h
  *
- * This header file is used in conjuction with the parseAFM.c file.
+ * This header file is used in conjunction with the parseAFM.c file.
  * Together these files provide the functionality to parse Adobe Font
  * Metrics files and store the information in predefined data structures.
  * It is intended to work with an application program that needs font metric
@@ -316,7 +316,7 @@ typedef struct
  *
  *  "fp" should be a valid file pointer to an AFM file.
  *
- *  "fi" is a pointer to a pointer to a FontInfo record sturcture 
+ *  "fi" is a pointer to a pointer to a FontInfo record structure 
  *  (defined above). Storage for the FontInfo structure will be
  *  allocated in parseFile and the structure will be filled in
  *  with the requested data from the AFM File.

Modified: openoffice/trunk/main/vcl/unx/generic/printer/ppdparser.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/printer/ppdparser.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/printer/ppdparser.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/printer/ppdparser.cxx Tue Apr 29 19:25:03 2014
@@ -330,7 +330,7 @@ void PPDDecompressStream::Open( const rt
         }
         else
         {
-            // compression successfull, can get rid of file stream
+            // compression successful, can get rid of file stream
             delete mpFileStream, mpFileStream = NULL;
             mpMemStream->Seek( 0 );
         }

Modified: openoffice/trunk/main/vcl/unx/generic/window/FWS.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/window/FWS.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/window/FWS.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/window/FWS.cxx Tue Apr 29 19:25:03 2014
@@ -186,7 +186,7 @@ WMSupportsFWS (Display *display, int scr
  *
  * newHandler() -
  *
- * Handle X errors (temporarily) to record the occurance of BadWindow
+ * Handle X errors (temporarily) to record the occurrence of BadWindow
  * errors without crashing.  Used to detect the FWS_COMM_WINDOW root window
  * property containing an old or obsolete window id.
  *

Modified: openoffice/trunk/main/vcl/unx/generic/window/FWS.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/window/FWS.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/window/FWS.hxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/window/FWS.hxx Tue Apr 29 19:25:03 2014
@@ -37,7 +37,7 @@ extern "C" {
 Bool 
 WMSupportsFWS (Display *display, int screen);
 
-/* Send a client message to the FWS_COMM_WINDOW indicating the existance
+/* Send a client message to the FWS_COMM_WINDOW indicating the existence
  * of a new FWS client window.  Be careful to avoid BadWindow errors on
  * the XSendEvent in case the FWS_COMM_WINDOW root window property had
  * old/obsolete junk in it.

Modified: openoffice/trunk/main/vcl/unx/generic/window/salframe.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/window/salframe.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/window/salframe.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/window/salframe.cxx Tue Apr 29 19:25:03 2014
@@ -3519,7 +3519,7 @@ long X11SalFrame::HandleKeyEvent( XKeyEv
 		{
 			if ( ! CallCallback(SALEVENT_KEYINPUT, &aKeyEvt) )
 			{
-				// independent layer doesnt want to handle key-event, so check
+				// independent layer doesn't want to handle key-event, so check
 				// whether the keycode may have an alternate meaning
 				KeyAlternate aAlternate = GetAlternateKeyCode( nKeyCode );
 				if ( aAlternate.nKeyCode != 0 )
@@ -3958,7 +3958,7 @@ long X11SalFrame::HandleReparentEvent( X
 
 
     // limit width and height if we are too large: #47757
-    // olwm and fvwm need this, it doesnt harm the rest
+    // olwm and fvwm need this, it doesn't harm the rest
 
     // #i81311# do this only for sizable frames
     if( (nStyle_ & SAL_FRAME_STYLE_SIZEABLE) != 0 )

Modified: openoffice/trunk/main/vcl/unx/gtk/a11y/atkwindow.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/gtk/a11y/atkwindow.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/gtk/a11y/atkwindow.cxx (original)
+++ openoffice/trunk/main/vcl/unx/gtk/a11y/atkwindow.cxx Tue Apr 29 19:25:03 2014
@@ -190,7 +190,7 @@ ooo_window_wrapper_real_initialize(AtkOb
             Reference< XAccessible > xAccessible( pWindow->GetAccessible(true) );
 
             /* We need the wrapper object for the top-level XAccessible to be
-             * in the wrapper registry when atk traverses the hierachy up on
+             * in the wrapper registry when atk traverses the hierarchy up on
              * focus events
              */
             if( WINDOW_BORDERWINDOW == pWindow->GetType() )

Modified: openoffice/trunk/main/vcl/unx/gtk/a11y/atkwrapper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/gtk/a11y/atkwrapper.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/gtk/a11y/atkwrapper.cxx (original)
+++ openoffice/trunk/main/vcl/unx/gtk/a11y/atkwrapper.cxx Tue Apr 29 19:25:03 2014
@@ -864,9 +864,9 @@ atk_object_wrapper_new( const ::com::sun
         else
         {
             /* gail_focus_tracker remembers the focused object at the first
-             * parent in the hierachy that is a Gtk+ widget, but at the time the
+             * parent in the hierarchy that is a Gtk+ widget, but at the time the
              * event gets processed (at idle), it may be too late to create the
-             * hierachy, so doing it now ..
+             * hierarchy, so doing it now ..
              */
             uno::Reference< accessibility::XAccessible > xParent( xContext->getAccessibleParent() );
 

Modified: openoffice/trunk/main/vcl/unx/gtk/app/gtkdata.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/gtk/app/gtkdata.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/gtk/app/gtkdata.cxx (original)
+++ openoffice/trunk/main/vcl/unx/gtk/app/gtkdata.cxx Tue Apr 29 19:25:03 2014
@@ -633,7 +633,7 @@ void GtkXLib::Init()
 
     g_set_application_name(X11SalData::getFrameClassName());
 
-    // Set consistant name of the root accessible
+    // Set consistent name of the root accessible
     rtl::OUString aAppName = Application::GetAppName();
     if( aAppName.getLength() > 0 )
     {

Modified: openoffice/trunk/main/vcl/unx/gtk/gdi/salnativewidgets-gtk.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/gtk/gdi/salnativewidgets-gtk.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/gtk/gdi/salnativewidgets-gtk.cxx (original)
+++ openoffice/trunk/main/vcl/unx/gtk/gdi/salnativewidgets-gtk.cxx Tue Apr 29 19:25:03 2014
@@ -449,7 +449,7 @@ void GtkData::deInitNWF( void )
     {
         // free up global widgets
         // gtk_widget_destroy will in turn destroy the child hierarchy
-        // so only destroy disjunct hierachies
+        // so only destroy disjunct hierarchies
         if( gWidgetData[i].gCacheWindow )
             gtk_widget_destroy( gWidgetData[i].gCacheWindow );
         if( gWidgetData[i].gMenuWidget )

Modified: openoffice/trunk/main/vcl/unx/gtk/window/gtkframe.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/gtk/window/gtkframe.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/gtk/window/gtkframe.cxx (original)
+++ openoffice/trunk/main/vcl/unx/gtk/window/gtkframe.cxx Tue Apr 29 19:25:03 2014
@@ -3515,7 +3515,7 @@ bool GtkSalFrame::IMHandler::handleKeyEv
 /* FIXME:
 * #122282# still more hacking: some IMEs never start a preedit but simply commit
 * in this case we cannot commit a single character. Workaround: do not do the
-* single key hack for enter or space if the unicode commited does not match
+* single key hack for enter or space if the unicode committed does not match
 */
 
 static bool checkSingleKeyCommitHack( guint keyval, sal_Unicode cCode )

Modified: openoffice/trunk/main/vcl/unx/kde/salnativewidgets-kde.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/kde/salnativewidgets-kde.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/kde/salnativewidgets-kde.cxx (original)
+++ openoffice/trunk/main/vcl/unx/kde/salnativewidgets-kde.cxx Tue Apr 29 19:25:03 2014
@@ -795,7 +795,7 @@ QPushButton *WidgetPainter::pushButton( 
     // Workaround for broken styles which do not add
     // QStyle::PM_ButtonDefaultIndicator to the size of the default button
     // (for example Keramik)
-    // FIXME Fix Keramik style to be consistant with Qt built-in styles. Aargh!
+    // FIXME Fix Keramik style to be consistent with Qt built-in styles. Aargh!
     if ( bDefault )
     {
 	QSize qContentsSize( 50, 50 );

Modified: openoffice/trunk/main/vcl/win/source/app/salinst.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/win/source/app/salinst.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/win/source/app/salinst.cxx (original)
+++ openoffice/trunk/main/vcl/win/source/app/salinst.cxx Tue Apr 29 19:25:03 2014
@@ -771,7 +771,7 @@ LRESULT CALLBACK SalComWndProc( HWND hWn
 			rDef = FALSE;
 			break;
 		// If we get this message, because another GetMessage() call
-		// has recieved this message, we must post this message to
+		// has received this message, we must post this message to
 		// us again, because in the other case we wait forever.
 		case SAL_MSG_RELEASEWAITYIELD:
 			{

Modified: openoffice/trunk/main/vcl/win/source/app/saltimer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/win/source/app/saltimer.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/win/source/app/saltimer.cxx (original)
+++ openoffice/trunk/main/vcl/win/source/app/saltimer.cxx Tue Apr 29 19:25:03 2014
@@ -117,7 +117,7 @@ void CALLBACK SalTimerProc( HWND, UINT, 
         bool bRecursive = pSalData->mbInTimerProc && (nId != SALTIMERPROC_RECURSIVE);
 	    if ( pSVData->mpSalTimer && ! bRecursive )
 	    {
-		    // Try to aquire the mutex. If we don't get the mutex then we
+		    // Try to acquire the mutex. If we don't get the mutex then we
 		    // try this a short time later again.
 		    if ( ImplSalYieldMutexTryToAcquire() )
 		    {

Modified: openoffice/trunk/main/vcl/win/source/gdi/salgdi.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/win/source/gdi/salgdi.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/win/source/gdi/salgdi.cxx (original)
+++ openoffice/trunk/main/vcl/win/source/gdi/salgdi.cxx Tue Apr 29 19:25:03 2014
@@ -354,7 +354,7 @@ void ImplFreeSalGDI()
 		pSalData->mhDitherPal = 0;
 	}
 
-	// delete buffers for dithering DIB patterns, if neccessary
+	// delete buffers for dithering DIB patterns, if necessary
 	if ( pSalData->mhDitherDIB )
 	{
 		GlobalUnlock( pSalData->mhDitherDIB );
@@ -1087,7 +1087,7 @@ void WinSalGraphics::SetLineColor()
 	HPEN hNewPen = GetStockPen( NULL_PEN );
 	HPEN hOldPen = SelectPen( getHDC(), hNewPen );
 
-	// destory or save old pen
+	// destroy or save old pen
 	if ( mhPen )
 	{
 		if ( !mbStockPen )
@@ -1145,7 +1145,7 @@ void WinSalGraphics::SetLineColor( SalCo
 	// select new pen
 	HPEN hOldPen = SelectPen( getHDC(), hNewPen );
 
-	// destory or save old pen
+	// destroy or save old pen
 	if ( mhPen )
 	{
 		if ( !mbStockPen )
@@ -1169,7 +1169,7 @@ void WinSalGraphics::SetFillColor()
 	HBRUSH hNewBrush = GetStockBrush( NULL_BRUSH );
 	HBRUSH hOldBrush = SelectBrush( getHDC(), hNewBrush );
 
-	// destory or save old brush
+	// destroy or save old brush
 	if ( mhBrush )
 	{
 		if ( !mbStockBrush )
@@ -1273,7 +1273,7 @@ void WinSalGraphics::SetFillColor( SalCo
 	// select new brush
 	HBRUSH hOldBrush = SelectBrush( getHDC(), hNewBrush );
 
-	// destory or save old brush
+	// destroy or save old brush
 	if ( mhBrush )
 	{
 		if ( !mbStockBrush )

Modified: openoffice/trunk/main/vcl/win/source/gdi/salgdi2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/win/source/gdi/salgdi2.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/win/source/gdi/salgdi2.cxx (original)
+++ openoffice/trunk/main/vcl/win/source/gdi/salgdi2.cxx Tue Apr 29 19:25:03 2014
@@ -270,7 +270,7 @@ void WinSalGraphics::copyArea( long nDes
 			{
                 // hInvalidateRgn contains the fully visible parts of the original srcRect
 				hTempRgn = CreateRectRgnIndirect( &aSrcRect );
-                // substract it from the original rect to get the occluded parts
+                // subtract it from the original rect to get the occluded parts
 				nRgnType = CombineRgn( hInvalidateRgn, hTempRgn, hInvalidateRgn, RGN_DIFF );
 				DeleteRegion( hTempRgn );
 
@@ -709,7 +709,7 @@ SalBitmap* WinSalGraphics::getBitmap( lo
     else
     {
         err = GetLastError();
-        // #124826# avoid resource leak ! happens when runing without desktop access (remote desktop, service, may be screensavers)
+        // #124826# avoid resource leak ! happens when running without desktop access (remote desktop, service, may be screensavers)
         DeleteBitmap( hBmpBitmap );
     }
 

Modified: openoffice/trunk/main/vcl/win/source/gdi/salgdi3.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/win/source/gdi/salgdi3.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/win/source/gdi/salgdi3.cxx (original)
+++ openoffice/trunk/main/vcl/win/source/gdi/salgdi3.cxx Tue Apr 29 19:25:03 2014
@@ -406,7 +406,7 @@ static Unicode2LangType aLangFromCodeCha
 // get language matching to the missing char
 LanguageType MapCharToLanguage( sal_UCS4 uChar )
 {
-	// entries marked with default-CJK get replaced with the prefered CJK language
+	// entries marked with default-CJK get replaced with the preferred CJK language
 	static bool bFirst = true;
 	if( bFirst )
 	{
@@ -450,7 +450,7 @@ LanguageType MapCharToLanguage( sal_UCS4
 				break;
 		}
 
-		// change the marked entries to prefered language
+		// change the marked entries to preferred language
 		static const int nCount = (sizeof(aLangFromCodeChart) / sizeof(*aLangFromCodeChart));
 		for( int i = 0; i < nCount; ++i )
 		{
@@ -547,7 +547,7 @@ bool WinGlyphFallbackSubstititution::Has
 }
 
 // find a fallback font for missing characters
-// TODO: should stylistic matches be searched and prefered?
+// TODO: should stylistic matches be searched and preferred?
 bool WinGlyphFallbackSubstititution::FindFontSubstitute( ImplFontSelectData& rFontSelData, rtl::OUString& rMissingChars ) const
 {
 	// guess a locale matching to the missing chars

Modified: openoffice/trunk/main/vcl/win/source/window/salframe.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/win/source/window/salframe.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/win/source/window/salframe.cxx (original)
+++ openoffice/trunk/main/vcl/win/source/window/salframe.cxx Tue Apr 29 19:25:03 2014
@@ -1582,7 +1582,7 @@ void WinSalFrame::SetPosSize( long nX, l
             aRect.bottom = pt.y+2;
 
             // dualmonitor support:
-            // Get screensize of the monitor whith the mouse pointer
+            // Get screensize of the monitor with the mouse pointer
             ImplSalGetWorkArea( mhWnd, &aRect, &aRect );
 
             nX = ((aRect.right-aRect.left)-nWidth)/2 + aRect.left;
@@ -4177,7 +4177,7 @@ static void SetMaximizedFrameGeometry( H
     // calculate and set frame geometry of a maximized window - useful if the window is still hidden
 
     // dualmonitor support:
-    // Get screensize of the monitor whith the mouse pointer
+    // Get screensize of the monitor with the mouse pointer
 
     RECT aRectMouse;
     if( ! pParentRect )
@@ -4841,7 +4841,7 @@ static int ImplMenuChar( HWND, WPARAM wP
     if( nFound == 1 )
         nRet = MAKELRESULT( idxFound, MNC_EXECUTE );
     else
-        // duplicate mnemonics, just select the next occurence
+        // duplicate mnemonics, just select the next occurrence
         nRet = MAKELRESULT( idxFound, MNC_SELECT );
 
     return nRet;
@@ -5111,7 +5111,7 @@ static int ImplHandleMenuSelect( HWND hW
     long nRet = 0;
     if ( hMenu && !pFrame->mLastActivatedhMenu )
     {
-        // we never activated a menu (ie, no WM_INITMENUPOPUP has occured yet)
+        // we never activated a menu (ie, no WM_INITMENUPOPUP has occurred yet)
         // which means this must be the menubar -> send activation/deactivation
         SalMenuEvent aMenuEvt;
         WinSalMenuItem *pSalMenuItem = ImplGetSalMenuItem( hMenu, nId, bByPosition );
@@ -6208,7 +6208,7 @@ LRESULT CALLBACK SalFrameWndProc( HWND h
 
 					if (Application::GetSettings().GetMiscSettings().GetEnableATToolSupport())
 					{
-						// Make sure to launch Accessibiliity only the following criterias are satisfied to avoid RFT interrupts regular acc processing
+						// Make sure to launch Accessibiliity only the following criteria are satisfied to avoid RFT interrupts regular acc processing
 						if (g_acc_manager1 == NULL)
 						{
 							sal_Bool bCancelled(sal_False);

Modified: openoffice/trunk/main/vos/inc/vos/pipe.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vos/inc/vos/pipe.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vos/inc/vos/pipe.hxx (original)
+++ openoffice/trunk/main/vos/inc/vos/pipe.hxx Tue Apr 29 19:25:03 2014
@@ -172,13 +172,13 @@ public:
         @param pBuffer [in] Points to a buffer that contains the send-data.
         @param BytesToSend [in] The number of bytes to send. pBuffer must have at least
         this size.
-        @return the number of transfered bytes.
+        @return the number of transferred bytes.
     */
     sal_Int32 SAL_CALL send(const void* pBuffer, sal_uInt32 BytesToSend);
 
-    /** Delivers a constant decribing the last error for the pipe system.
-        @return ENONE if no error occured, invalid_PipeError if
-        an unknown (unmapped) error occured, otherwise an enum describing the
+    /** Delivers a constant describing the last error for the pipe system.
+        @return ENONE if no error occurred, invalid_PipeError if
+        an unknown (unmapped) error occurred, otherwise an enum describing the
         error.
     */
     TPipeError SAL_CALL getError() const;

Modified: openoffice/trunk/main/vos/inc/vos/process.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vos/inc/vos/process.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vos/inc/vos/signal.hxx (original)
+++ openoffice/trunk/main/vos/inc/vos/signal.hxx Tue Apr 29 19:25:03 2014
@@ -72,7 +72,7 @@ public:
 	/// Constructor 
 	OSignalHandler();              
 
-	/// Destructor kills thread if neccessary
+	/// Destructor kills thread if necessary
 	virtual ~OSignalHandler();
 
 	static TSignalAction SAL_CALL raise(sal_Int32 Signal, void *pData = 0);

Modified: openoffice/trunk/main/vos/inc/vos/socket.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vos/inc/vos/socket.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vos/inc/vos/thread.hxx (original)
+++ openoffice/trunk/main/vos/inc/vos/thread.hxx Tue Apr 29 19:25:03 2014
@@ -87,7 +87,7 @@ public:
 	/// Constructor 
 	OThread();              
 
-	/// Destructor kills thread if neccessary
+	/// Destructor kills thread if necessary
 	virtual ~OThread();
 
 	/** Create running instance of a thread.
@@ -211,7 +211,7 @@ public:
 	virtual ~OThreadData();
 
 	/** Set the data associated with the data key.
-		@returns True if operation was successfull
+		@returns True if operation was successful
 	*/
 	sal_Bool SAL_CALL setData(void *pData);
 

Modified: openoffice/trunk/main/vos/source/pipe.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vos/source/pipe.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vos/source/pipe.cxx (original)
+++ openoffice/trunk/main/vos/source/pipe.cxx Tue Apr 29 19:25:03 2014
@@ -346,7 +346,7 @@ sal_Int32 OStreamPipe::read(void* pBuffe
 {
 	VOS_ASSERT(m_pPipeRef && (*m_pPipeRef)());
 
-	/* loop until all desired bytes were read or an error occured */
+	/* loop until all desired bytes were read or an error occurred */
 	sal_Int32 BytesRead= 0;
 	sal_Int32 BytesToRead= n;
 	while (BytesToRead > 0) 
@@ -356,7 +356,7 @@ sal_Int32 OStreamPipe::read(void* pBuffe
 						 	    pBuffer, 
 								BytesToRead);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;
@@ -377,7 +377,7 @@ sal_Int32 OStreamPipe::write(const void*
 {
 	VOS_ASSERT(m_pPipeRef && (*m_pPipeRef)());
 
-	/* loop until all desired bytes were send or an error occured */
+	/* loop until all desired bytes were send or an error occurred */
 	sal_Int32 BytesSend= 0;
 	sal_Int32 BytesToSend= n;
 	while (BytesToSend > 0) 
@@ -388,7 +388,7 @@ sal_Int32 OStreamPipe::write(const void*
 								pBuffer, 
 								BytesToSend);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;

Modified: openoffice/trunk/main/vos/source/socket.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vos/source/socket.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vos/source/socket.cxx (original)
+++ openoffice/trunk/main/vos/source/socket.cxx Tue Apr 29 19:25:03 2014
@@ -1412,7 +1412,7 @@ sal_Int32 OStreamSocket::read(void* pBuf
         return -1;    
     }
     
-	/* loop until all desired bytes were read or an error occured */
+	/* loop until all desired bytes were read or an error occurred */
 	sal_uInt32 BytesRead= 0;
 	sal_uInt32 BytesToRead= n;
 	while (BytesToRead > 0)
@@ -1423,7 +1423,7 @@ sal_Int32 OStreamSocket::read(void* pBuf
 								   BytesToRead,
 								   osl_Socket_MsgNormal);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;
@@ -1459,7 +1459,7 @@ sal_Int32 OStreamSocket::write(const voi
         return -1;    
     }
     
-	/* loop until all desired bytes were send or an error occured */
+	/* loop until all desired bytes were send or an error occurred */
 	sal_uInt32 BytesSend= 0;
 	sal_uInt32 BytesToSend= n;
 	while (BytesToSend > 0)
@@ -1471,7 +1471,7 @@ sal_Int32 OStreamSocket::write(const voi
 								BytesToSend,
 								osl_Socket_MsgNormal);
 
-		/* error occured? */
+		/* error occurred? */
 		if(RetVal <= 0)
 		{
 			break;

Modified: openoffice/trunk/main/winaccessibility/source/UAccCOM/EnumVariant.cpp
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/winaccessibility/source/UAccCOM/EnumVariant.cpp?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/winaccessibility/source/UAccCOM/EnumVariant.cpp (original)
+++ openoffice/trunk/main/winaccessibility/source/UAccCOM/EnumVariant.cpp Tue Apr 29 19:25:03 2014
@@ -178,7 +178,7 @@ long CEnumVariant::GetCountOfElements()
 }
 
 /**
-   * Set memeber m_pXAccessibleSelection to NULL and m_lCurrent to m_lLBound.
+   * Set member m_pXAccessibleSelection to NULL and m_lCurrent to m_lLBound.
    * @param.
    * @return Result
    */

Modified: openoffice/trunk/main/winaccessibility/source/UAccCOM/MAccessible.cpp
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/winaccessibility/source/UAccCOM/MAccessible.cpp?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/winaccessibility/source/UAccCOM/MAccessible.cpp (original)
+++ openoffice/trunk/main/winaccessibility/source/UAccCOM/MAccessible.cpp Tue Apr 29 19:25:03 2014
@@ -110,7 +110,7 @@ BSTR IA2_STATES_NAME[] =
 	_T("Horizontal"),
 	_T("Iconified"),
 	_T("Invalid Entry"),
-	_T("Manages Decendents"),
+	_T("Manages Descendants"),
 	_T("Modal"),
 	_T("Multi Line"),
 	_T("Opaque"),
@@ -1502,7 +1502,7 @@ IMAccessible* CMAccessible::GetNavigateC
 
 /**
 * Return first child for parent container, process differently according 
-* to whether it is decendant manage
+* to whether it is descendant manage
 * @param	varStart, the start child id of this navigation action.
 * @param	pvarEndUpAt, [in,out] the end up child of this navigation action.
 * @return   S_OK if successful and E_FAIL if failure.
@@ -1539,7 +1539,7 @@ HRESULT CMAccessible::GetFirstChild(VARI
 
 /**
 * Return last child for parent container, process differently according 
-* to whether it is decendant manage
+* to whether it is descendant manage
 * @param	varStart, the start child id of this navigation action.
 * @param	pvarEndUpAt, [in,out] the end up child of this navigation action.
 * @return   S_OK if successful and E_FAIL if failure.
@@ -1574,7 +1574,7 @@ HRESULT CMAccessible::GetLastChild(VARIA
 }
 
 /**
-* The method GetNextSibling is general, whatever it is decendant manage or not
+* The method GetNextSibling is general, whatever it is descendant manage or not
 * Get the next sibling object.
 * @param	varStart, the start child id of this navigation action.
 * @param	pvarEndUpAt, [in,out] the end up child of this navigation action.
@@ -1609,7 +1609,7 @@ HRESULT CMAccessible::GetNextSibling(VAR
 }
 
 /**
-*the method GetPreSibling is general, whatever it is decendant manage or not
+*the method GetPreSibling is general, whatever it is descendant manage or not
 * @param	varStart, the start child id of this navigation action.
 * @param	pvarEndUpAt, [in,out] the end up child of this navigation action.
 * @return   S_OK if successful and E_FAIL if failure.

Modified: openoffice/trunk/main/winaccessibility/source/UAccCOM/MAccessible.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/winaccessibility/source/UAccCOM/MAccessible.h?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/winaccessibility/source/service/AccObject.cxx (original)
+++ openoffice/trunk/main/winaccessibility/source/service/AccObject.cxx Tue Apr 29 19:25:03 2014
@@ -94,7 +94,7 @@ AccObject::~AccObject()
 /**
    * Insert a child element.
    * @param pChild Child element that should be inserted into child list.
-   * @param pos Insert postion.
+   * @param pos Insert position.
    * @return
    */
 void AccObject::InsertChild( AccObject* pChild,short pos )
@@ -120,7 +120,7 @@ void AccObject::InsertChild( AccObject* 
 /**
    * Delete a child element
    * @param pChild Child element that should be inserted into child list.
-   * @param pos Insert postion.
+   * @param pos Insert position.
    * @return
    */
 void AccObject::DeleteChild( AccObject* pChild )

Modified: openoffice/trunk/main/winaccessibility/source/service/AccObjectManagerAgent.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/winaccessibility/source/service/AccObjectManagerAgent.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/winaccessibility/source/service/AccObjectManagerAgent.cxx (original)
+++ openoffice/trunk/main/winaccessibility/source/service/AccObjectManagerAgent.cxx Tue Apr 29 19:25:03 2014
@@ -238,7 +238,7 @@ void  AccObjectManagerAgent::UpdateState
 }
 
 /**
-   * Interface of notify MSAA event when some UNO event occured.
+   * Interface of notify MSAA event when some UNO event occurred.
    * @param pXAcc Uno XAccessible interface of control.
    * @param pEvent UNO event ID.
    * @return If the method is correctly processed.

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/AgendaTemplate.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/AgendaTemplate.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/AgendaTemplate.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/AgendaTemplate.java Tue Apr 29 19:25:03 2014
@@ -358,7 +358,7 @@ public class AgendaTemplate extends Text
 
     /**
      * itemsCache is a Map containing all agenda item. These are object which 
-     * "write themselfs" to the table, given a table cursor.
+     * "write themselves" to the table, given a table cursor.
      * A cache is used in order to reuse the objects, instead of recreate them.
      * This method fills the cache will all items objects (names and headings).
      */
@@ -483,7 +483,7 @@ public class AgendaTemplate extends Text
     }
 
     /**
-     * locates the titles (name, location, date, time) and saves a reference to thier Text ranges.
+     * locates the titles (name, location, date, time) and saves a reference to their Text ranges.
      *
      */
     private void initializeTitles()
@@ -1019,7 +1019,7 @@ public class AgendaTemplate extends Text
                 String cellName = PropertyNames.EMPTY_STRING;
 
                 /* now go through all items that belong to this
-                 * table. Check each one agains the model. If it should
+                 * table. Check each one against the model. If it should
                  * be display, call it's write method.
                  * All items are of type AgendaItem which means they write 
                  * two cells to the table: a title (text) and a placeholder.

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/AgendaWizardDialogImpl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/AgendaWizardDialogImpl.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/AgendaWizardDialogImpl.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/AgendaWizardDialogImpl.java Tue Apr 29 19:25:03 2014
@@ -277,7 +277,7 @@ public class AgendaWizardDialogImpl exte
         });
     }
 
-    /** used in developement to start the wizard */
+    /** used in development to start the wizard */
     public static void main(String args[])
     {
         String ConnectStr = "uno:socket,host=127.0.0.1,port=8100;urp,negotiate=0,forcesynchronous=1;StarOffice.ServiceManager";
@@ -357,10 +357,10 @@ public class AgendaWizardDialogImpl exte
     private FileAccess fileAccess1;
     /** convenience method.
      *  instead of creating a FileAccess object every time
-     *  it is needed, I have a FileAccess object memeber.
+     *  it is needed, I have a FileAccess object member.
      *  the first time it is needed it will be created, and
      *  then be reused...
-     * @return the FileAccess memeber object.
+     * @return the FileAccess member object.
      */
     private FileAccess getFileAccess() {
         if (fileAccess1 == null)
@@ -411,7 +411,7 @@ public class AgendaWizardDialogImpl exte
     /**
      * is called when the user
      * changes the path through the "save as" dialog.
-     * The path displayed is a translated, user-friendly, platform dependant path.
+     * The path displayed is a translated, user-friendly, platform dependent path.
      * @param url the new save url.
      */
     private void setFilename(String url) {

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/TopicsControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/TopicsControl.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/TopicsControl.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/agenda/TopicsControl.java Tue Apr 29 19:25:03 2014
@@ -51,7 +51,7 @@ import com.sun.star.wizards.ui.event.Met
  * @author rpiterman
  * This class implements the UI functionality of the topics scroller control.
  * <br/>
- * During developement, there has been a few changes which were not *fully* done - 
+ * During development, there has been a few changes which were not *fully* done - 
  * mainly in converting the topics and time boxes from combobox and time box to normal textboxes,
  * so in the code they might be referenced as combobox or timebox. This should be 
  * rather understood as topicstextbox and timetextbox.
@@ -142,7 +142,7 @@ public class TopicsControl extends Contr
 
     /**
      * create a new TopicControl. Since this is used specifically for the
-     * agenda dialog, I use step 5, and constant location - and need no paramter...
+     * agenda dialog, I use step 5, and constant location - and need no parameter...
      * @param dialog the parent dialog
      * @param xmsf service factory
      * @param agenda the Agenda configuration data (contains the current topics data).

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/common/ConfigNode.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/common/ConfigNode.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/common/ConfigNode.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/common/ConfigNode.java Tue Apr 29 19:25:03 2014
@@ -24,7 +24,7 @@ package com.sun.star.wizards.common;
 
 /**
  * This Interface specifies a method of an object which is 
- * capable of reading adn writing its data out of the 
+ * capable of reading and writing its data out of the 
  * OO Configuration. <br/>
  * There are 2 direct implementations: ConfigGroup and ConfigSet.
  * The root is the first Java Object in the configuration hirarchie.

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/common/Helper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/common/Helper.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/common/Helper.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/common/Helper.java Tue Apr 29 19:25:03 2014
@@ -279,7 +279,7 @@ public class Helper
      * @author bc93774
      * checks if the value of an object that represents an array is null.
      * check beforehand if the Object is really an array with "AnyConverter.IsArray(oObject)
-     * @param oValue the paramter that has to represent an object
+     * @param oValue the parameter that has to represent an object
      * @return a null reference if the array is empty
      */
     public static Object getArrayValue(Object oValue)

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/common/NumericalHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/common/NumericalHelper.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/common/NumericalHelper.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/common/NumericalHelper.java Tue Apr 29 19:25:03 2014
@@ -63,7 +63,7 @@ public class NumericalHelper
      */
     private NumericalHelper()
     {
-        // private c'tor, so noone can instantiate
+        // private c'tor, so no one can instantiate
     }
 
     /**
@@ -1555,7 +1555,7 @@ public class NumericalHelper
                 /* converison idea: every digit is written with a maximum of two
                  * different roman symbols, using three in total, e.g. CC, CD, 
                  * DCC, CM for the hundreds (meaning 200, 400, 700 and 900).
-                 * So every digit is converted seperately with regard to the
+                 * So every digit is converted separately with regard to the
                  * special cases 4 and 9.
                  */
                 int symbolIndex = 0;

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/common/SystemDialog.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/common/SystemDialog.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/common/SystemDialog.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/common/SystemDialog.java Tue Apr 29 19:25:03 2014
@@ -353,7 +353,7 @@ public class SystemDialog
     }
 
     /**
-     * just like the other showMessageBox(...) method, but recieves a
+     * just like the other showMessageBox(...) method, but receives a
      * peer argument to use to create the message box.
      * @param xMSF
      * @param peer

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/reportbuilder/layout/ReportBuilderLayouter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/reportbuilder/layout/ReportBuilderLayouter.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/reportbuilder/layout/ReportBuilderLayouter.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/reportbuilder/layout/ReportBuilderLayouter.java Tue Apr 29 19:25:03 2014
@@ -1262,7 +1262,7 @@ abstract public class ReportBuilderLayou
                         XShape aShape = UnoRuntime.queryInterface(XShape.class, aClone);
 
                         // normally 'createClone' will create a real clone of the component,
-                        // but there seems some problems, we have to controll.
+                        // but there seems some problems, we have to control.
                         copyProperties(aComponent, aClone);
 
                         // aShape.setPosition(aComponent.getPosition());

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/ui/DocumentPreview.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/ui/DocumentPreview.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/ui/DocumentPreview.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/ui/DocumentPreview.java Tue Apr 29 19:25:03 2014
@@ -134,7 +134,7 @@ public class DocumentPreview
 
     /*********************************************************************
     create a new frame with a new container window inside,
-    which isnt part of the global frame tree.
+    which isn't part of the global frame tree.
     
     Attention:
     a) This frame wont be destroyed by the office. It must be closed by you!

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/ui/UnoDialog2.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/ui/UnoDialog2.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/ui/UnoDialog2.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/ui/UnoDialog2.java Tue Apr 29 19:25:03 2014
@@ -336,7 +336,7 @@ public class UnoDialog2 extends UnoDialo
                     });
             Helper.setUnoPropertyValues(xControlModel, sPropNames, oPropValues);
             //setControlPropertiesDebug(xControlModel, sPropNames, oPropValues);
-            //System.out.println("  Setting props successfull !");
+            //System.out.println("  Setting props successful !");
             Helper.setUnoPropertyValue(xControlModel, PropertyNames.PROPERTY_NAME, componentName);
         }
         catch (Exception ex)

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/ui/event/DataAware.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/ui/event/DataAware.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/ui/event/DataAware.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/ui/event/DataAware.java Tue Apr 29 19:25:03 2014
@@ -222,12 +222,12 @@ public abstract class DataAware {
     /**
      * Value objects read and write a value from and
      * to an object. Typically using reflection and JavaBeans properties 
-     * or directly using memeber reflection API.
+     * or directly using member reflection API.
      * DataAware delegates the handling of the DataObject
      * to a Value object.
      * 2 implementations currently exist: PropertyValue,
      * using JavaBeans properties reflection, and DataAwareFields classes
-     * which implement different memeber types.
+     * which implement different member types.
      */
     public interface Value {
         /**
@@ -246,7 +246,7 @@ public abstract class DataAware {
          * checks if this Value object can handle
          * the given object type as a target.
          * @param type the type of a target to check
-         * @return true if the given class is acceptible for
+         * @return true if the given class is acceptable for
          * the Value object. False if not.
          */
         public boolean isAssignable(Class type);

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/web/FTPDialog.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/web/FTPDialog.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/web/FTPDialog.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/web/FTPDialog.java Tue Apr 29 19:25:03 2014
@@ -58,7 +58,7 @@ import com.sun.star.wizards.common.HelpI
  * (*) entering FTP server and user information.
  * (*) testing the connection.
  * (*) choosing a directory on the server.
- * If a connection was established succesfully, the user may
+ * If a connection was established successfully, the user may
  * press OK, which will change
  * the CGPublish object propertiers according the user's input.
  * If no connection was established. the OK and Choose-Dir button are disabled.

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/web/ImageListDialog.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/web/ImageListDialog.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/web/ImageListDialog.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/web/ImageListDialog.java Tue Apr 29 19:25:03 2014
@@ -56,7 +56,7 @@ import com.sun.star.wizards.ui.ImageList
  * so dialogs which do not need those, should set the corresponding
  * members showDeselectButton and/or showOtherButton to false.
  * <br/>
- * the consturctor should recieve, among others, an Array of String resources - see 
+ * the consturctor should receive, among others, an Array of String resources - see 
  * constructor documentation for details.
  * 
  * @author rpiterman

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/web/Process.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/web/Process.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/web/Process.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/web/Process.java Tue Apr 29 19:25:03 2014
@@ -530,7 +530,7 @@ public class Process implements WebWizar
             String fn = fileAccess.getPath(targetPath, key.substring(0, key.length() - 4));
             File f = new File(fn);
             FileOutputStream oStream = new FileOutputStream(f);
-            // Due to a problem occuring when using Xalan-Java 2.6.0 and
+            // Due to a problem occurring when using Xalan-Java 2.6.0 and
             // Java 1.5.0, wrap f in a FileOutputStream here (otherwise, the
             // StreamResult's getSystemId would return a "file:/..." URL while
             // the Xalan code expects a "file:///..." URL):
@@ -679,7 +679,7 @@ public class Process implements WebWizar
 
             /*
              * here I calculate the destination filename. 
-             * I take the original filename (docFilename), substract the extension, (docExt) -> (fn) 
+             * I take the original filename (docFilename), subtract the extension, (docExt) -> (fn) 
              * and find an available filename which starts with
              * this filename, but with the new extension. (destExt)
              */

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/web/ProcessStatusRenderer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/web/ProcessStatusRenderer.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/web/ProcessStatusRenderer.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/web/ProcessStatusRenderer.java Tue Apr 29 19:25:03 2014
@@ -29,7 +29,7 @@ import com.sun.star.wizards.common.IRend
 
 /**
  * @author rpiterman
- * recieves status calls from the status dialog which
+ * receives status calls from the status dialog which
  * apears when the user clicks "create". 
  * allocates strings from the resources to
  * display the current task status.

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/web/TOCPreview.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/web/TOCPreview.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/web/TOCPreview.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/web/TOCPreview.java Tue Apr 29 19:25:03 2014
@@ -47,8 +47,8 @@ import com.sun.star.wizards.web.data.CGS
  * Since the files are both static and dynamic (some are always the same, 
  * while other change according to user choices) 
  * I divide this tasks to two: all necessary 
- * static files, which should not regularily update are copied upon
- * instanciation.
+ * static files, which should not regularly update are copied upon
+ * instantiation.
  * The TOC is generated in refresh(...);
  */
 public class TOCPreview

Modified: openoffice/trunk/main/wizards/com/sun/star/wizards/web/WWD_Startup.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/web/WWD_Startup.java?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/web/WWD_Startup.java (original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/web/WWD_Startup.java Tue Apr 29 19:25:03 2014
@@ -75,7 +75,7 @@ import com.sun.star.wizards.web.data.CGS
  * </P>
  * <p>
  * A Value is either a JavaBean property with
- * a Getter and a Setter or a public class Memeber.
+ * a Getter and a Setter or a public class Member.
  * </P>
  * When the UI Control changes, the Value changes correspondingly.
  * This depends on settings a Listener which calls the updateData()
@@ -89,7 +89,7 @@ import com.sun.star.wizards.web.data.CGS
  * the updateUI() method whenever I change the Value.
  * </P>
  * To contain the Data, I use the Configuration Data Objects
- * which read themselfs out of the Configuration. they are all located under
+ * which read themselves out of the Configuration. they are all located under
  * the data package.
  * <p/>
  * Different groups of DataAware objects are grouped into vectors.
@@ -195,7 +195,7 @@ public abstract class WWD_Startup extend
     boolean __ftp;
     /**
      * When the wizard starts, a new document opens.
-     * The backgroundDoc memeber contains the TextDocument
+     * The backgroundDoc member contains the TextDocument
      * instance used for that purpose.
      */
     protected XFrame myFrame;
@@ -472,7 +472,7 @@ public abstract class WWD_Startup extend
 
             ConfigSet set = settings.cp_DefaultSession.cp_Publishing;
 
-            // now if path variables are used in publisher pathes, they
+            // now if path variables are used in publisher paths, they
             // are getting replaced here...
             for (int i = 0; i < set.getSize(); i++)
             {
--- openoffice/trunk/main/vos/inc/vos/process.hxx (original)
+++ openoffice/trunk/main/vos/inc/vos/process.hxx Tue Apr 29 19:25:03 2014
@@ -86,7 +86,7 @@ public:
 /** startup child processes.
     @see OStartupInfo
     Used for starting an monitoring child processes with special features:
-    <ul><li>setting enviroments,
+    <ul><li>setting environments,
     <li>setting working directories,
     <li>setting user rights and security,
     <li>providing ioresources like file descriptors and sockets.</ul>
@@ -116,7 +116,7 @@ public:
     enum TProcessError {
         E_None         = osl_Process_E_None,            /* no error */
         E_NotFound     = osl_Process_E_NotFound,        /* image not found */
-        E_TimedOut     = osl_Process_E_TimedOut,        /* timout occured */
+        E_TimedOut     = osl_Process_E_TimedOut,        /* timout occurred */
         E_NoPermission = osl_Process_E_NoPermission,    /* permission denied */
         E_Unknown      = osl_Process_E_Unknown,         /* unknown error */
         E_InvalidError = osl_Process_E_InvalidError     /* unmapped error */
@@ -171,7 +171,7 @@ public:
         If there are any ioresources provided from the calling process, this
         function returns only, if the child process calls OStartupInfo::acceptIOResource().
         @param Options [in] describes the execution mode.
-        @return only not eNONE, if too much enviroments are added.
+        @return only not eNONE, if too much environments are added.
         @see OStartupInfo::acceptIOResource
     */
     TProcessError SAL_CALL execute(TProcessOption Options,
@@ -186,7 +186,7 @@ public:
         function returns only, if the child process calls OStartupInfo::acceptIOResource().
         @param Options [in] describes the execution mode.
         @param Security [in] is a given security object for one logged in user.
-        @return eNONE, if the proccess could be executed, otherwise an errorcode.
+        @return eNONE, if the process could be executed, otherwise an errorcode.
         @see OStartupInfo::acceptIOResource
     */
     TProcessError SAL_CALL execute(TProcessOption Options,
@@ -228,7 +228,7 @@ public:
     enum TStartupError {
         E_None         = osl_Process_E_None,            /* no error */
         E_NotFound     = osl_Process_E_NotFound,        /* image not found */
-        E_TimedOut     = osl_Process_E_TimedOut,        /* timout occured */
+        E_TimedOut     = osl_Process_E_TimedOut,        /* timout occurred */
         E_NoPermission = osl_Process_E_NoPermission,    /* permission denied */
         E_Unknown      = osl_Process_E_Unknown,         /* unknown error */
         E_InvalidError = osl_Process_E_InvalidError     /* unmapped error */
@@ -256,11 +256,11 @@ public:
     TStartupError SAL_CALL getExecutableFile(::rtl::OUString& strImageName)
         const;
 
     /** Get the value of one enviroment variable.
         @param Name [in] denotes the name of the variable to get.
         @param Buffer [out] is the buffer where the value of this variable is returned.
         @param Max [in] is the size of this buffer.
-        @return eNONE, if the variable exist in the enviroment, otherwise False.
+        @return eNONE, if the variable exist in the environment, otherwise False.
     */
     TStartupError SAL_CALL getEnvironment(const ::rtl::OUString& strVar, ::rtl::OUString& strValue);
 };
@@ -256,11 +256,11 @@ public:
         const;
 
-    /** Get the value of one enviroment variable.
+    /** Get the value of one environment variable.
         @param Name [in] denotes the name of the variable to get.
         @param Buffer [out] is the buffer where the value of this variable is returned.

Modified: openoffice/trunk/main/vos/inc/vos/signal.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vos/inc/vos/signal.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/vos/inc/vos/socket.hxx (original)
+++ openoffice/trunk/main/vos/inc/vos/socket.hxx Tue Apr 29 19:25:03 2014
@@ -175,7 +175,7 @@ public:
 
     enum TResult {
         TResult_Ok          = osl_Socket_Ok,          /* successful completion */
-        TResult_Error       = osl_Socket_Error,       /* error occured, check osl_getLastSocketError() for details */
+        TResult_Error       = osl_Socket_Error,       /* error occurred, check osl_getLastSocketError() for details */
         TResult_TimedOut    = osl_Socket_TimedOut,    /* blocking operation timed out */
         TResult_Interrupted = osl_Socket_Interrupted, /* blocking operation was interrupted */
         TResult_InProgress  = osl_Socket_InProgress   /* nonblocking operation is in progress */
@@ -566,7 +566,7 @@ public:
         You can specify a timeout-value in seconds/nanoseconds that denotes
         how sal_Int32 the operation will block if the Socket is not ready.
         @return True if read operations (recv, recvFrom, accept) on the Socket
-        will NOT block; False if it would block or if an error occured.
+        will NOT block; False if it would block or if an error occurred.
 
         @param pTimeout if 0, the operation will block without a timeout. Otherwise
         the specified amout of time.
@@ -577,7 +577,7 @@ public:
         You can specify a timeout-value in seconds/nanoseconds that denotes
         how sal_Int32 the operation will block if the Socket is not ready.
         @return True if send operations (send, sendTo) on the Socket
-        will NOT block; False if it would block or if an error occured.
+        will NOT block; False if it would block or if an error occurred.
 
         @param pTimeout if 0, the operation will block without a timeout. Otherwise
         the specified amout of time.
@@ -589,7 +589,7 @@ public:
         how sal_Int32 the operation will block if the Socket has no pending OOB data.
 
         @return True if OOB-request operations (recv with appropriate flags)
-        on the Socket will NOT block; False if it would block or if an error occured.
+        on the Socket will NOT block; False if it would block or if an error occurred.
 
         @param pTimeout if 0, the operation will block without a timeout. Otherwise
         the specified amout of time.
@@ -633,7 +633,7 @@ public:
         </ul>
 
         @return The size of the attribute copied into pBuffer ot -1 if an error
-        occured.
+        occurred.
     */
     sal_Int32 SAL_CALL getOption(TSocketOption Option,
                       void* pBuffer,
@@ -779,7 +779,7 @@ public:
     sal_Int32   SAL_CALL setRecvBufSize(sal_Int32 size =-1) const;
 
     /** Disables the Nagle algorithm for send coalescing. (Do not
-        collect data until a packet is full, instead send immediatly.
+        collect data until a packet is full, instead send immediately.
         This increases network traffic but might improve response-times.)
         @param opt 1 sets, 0 resets, -1 won't change anything
         @return the previous setting
@@ -794,9 +794,9 @@ public:
     */
     void SAL_CALL getError(::rtl::OUString& strError) const;
 
-    /** Delivers a constant decribing the last error for the socket system.
-        @return ENONE if no error occured, invalid_SocketError if
-        an unknown (unmapped) error occured, otherwise an enum describing the
+    /** Delivers a constant describing the last error for the socket system.
+        @return ENONE if no error occurred, invalid_SocketError if
+        an unknown (unmapped) error occurred, otherwise an enum describing the
         error.
     */
     TSocketError SAL_CALL getError() const;
@@ -918,7 +918,7 @@ public:
         <li> TMsg_MaxIOVLen
         </ul>
 
-        @return the number of transfered bytes.
+        @return the number of transferred bytes.
     */
     sal_Int32 SAL_CALL send(const void* pBuffer,
                  sal_uInt32 BytesToSend,
@@ -1110,7 +1110,7 @@ public:
         <li> TMsg_MaxIOVLen
         </ul>
 
-        @return the number of transfered bytes.
+        @return the number of transferred bytes.
     */
     sal_Int32   SAL_CALL sendTo(const OSocketAddr& ReceiverAddr,
                    const void* pBuffer,

Modified: openoffice/trunk/main/vos/inc/vos/thread.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/vos/inc/vos/thread.hxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================
--- openoffice/trunk/main/winaccessibility/source/UAccCOM/MAccessible.h (original)
+++ openoffice/trunk/main/winaccessibility/source/UAccCOM/MAccessible.h Tue Apr 29 19:25:03 2014
@@ -244,7 +244,7 @@ private:
 
     // the helper methods in order to implement the above public methods
     IMAccessible* GetChildInterface(long dChildIndex);//notice here the parameter is child index,not child id
-    IMAccessible* GetNavigateChildForDM(VARIANT varCur,short flags);//for decendant manage
+    IMAccessible* GetNavigateChildForDM(VARIANT varCur,short flags);//for descendant manage
     HRESULT GetFirstChild(VARIANT varStart,VARIANT* pvarEndUpAt);//for accNavigate implementation
     HRESULT GetLastChild(VARIANT varStart,VARIANT* pvarEndUpAt);//for accNavigate implementation
     HRESULT GetNextSibling(VARIANT varStart,VARIANT* pvarEndUpAt);//for accNavigate implementation
@@ -265,7 +265,7 @@ private:
 public:
     STDMETHOD(Get_XAccChildID)(/*[out,retval]*/ long* childID);
     // AccObjectManagerAgent is a management object in UNO, here keep its pointer for
     // the implementation of accNavigate when decendant manage happens for List,Tree, or Table
     // AccObjectManagerAgent and the following UNO objects XAccessble,XAccessibleSelection,
     // XAccessibleAction are all used to operate UNO accessiblility information directly when
     // implement some specific MSAA methods,such as accSelection,accNavigate
@@ -265,7 +265,7 @@ private:
     STDMETHOD(Get_XAccChildID)(/*[out,retval]*/ long* childID);
     // AccObjectManagerAgent is a management object in UNO, here keep its pointer for
-    // the implementation of accNavigate when decendant manage happens for List,Tree, or Table
+    // the implementation of accNavigate when descendant manage happens for List,Tree, or Table
     // AccObjectManagerAgent and the following UNO objects XAccessble,XAccessibleSelection,
     // XAccessibleAction are all used to operate UNO accessiblility information directly when

Modified: openoffice/trunk/main/winaccessibility/source/service/AccObject.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/winaccessibility/source/service/AccObject.cxx?rev=1591062&r1=1591061&r2=1591062&view=diff
==============================================================================